Summary:	GUI for handling X509 certificates, RSA keys and PKCS#10 requests
Name:		xca
Version:	2.8.0
Release:	%mkrel 1
License:	BSD
Group:		System/Servers
URL:		https://hohnstaedt.de/xca/
Source0:	https://github.com/chris2511/xca/releases/download/RELEASE.%{version}/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Sql)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6ToolsTools)
BuildRequires:	qttools6
BuildRequires:	qttools6-assistant
BuildRequires:	db-devel
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(xkbcommon)
BuildRequires:	sphinx-build
BuildRequires:	linuxdoc-tools
BuildRequires:	libltdl-devel

%description
XCA uses a Berkeley DB for storage and supports RSA keys,
certificate signing requests (PKCS#10) and Certificates (X509v3)
The signing of requests, and the creation of self-signed certificates
is supported. Both can use templates for simplicity.
The PKI structures can be imported and exported in several formats
like PKCS#7, PKCS#12, PEM, DER, PKCS#8.

%prep
%autosetup -p1

perl -n -i -e '$/="\r\n";chomp;print;print "\n"' COPYRIGHT

%build
%cmake
%cmake_build

%install
%cmake_install

rm -f %{buildroot}%{_datadir}/pixmaps/xca-32x32.xpm

%files
%doc AUTHORS README.md
%{_docdir}/%{name}/*
%{_iconsdir}/hicolor/*/apps/*%{name}.png
%{_iconsdir}/hicolor/*/mimetypes/x-%{name}-*.png
%{_datadir}/applications/*.desktop
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/mime/packages/xca.xml
%{_datadir}/bash-completion/completions/%{name}
%{_metainfodir}/*.xml
%{_mandir}/man1/*.1*


%changelog
* Sat Jan 25 2025 daviddavid <daviddavid> 2.8.0-1.mga10
+ Revision: 2142109
- new version: 2.8.0

* Sat Sep 07 2024 daviddavid <daviddavid> 2.7.0-1.mga10
+ Revision: 2093476
- new version: 2.7.0
+ dlucio <dlucio>
- cmake(Qt6Network) as BR

* Wed Oct 25 2023 daviddavid <daviddavid> 2.5.0-1.mga10
+ Revision: 2001064
- new version: 2.5.0
- switch to cmake build system and Qt6

* Thu Mar 17 2022 danf <danf> 2.4.0-1.mga9
+ Revision: 1796217
- Update to ver. 2.4.0
- drop compatibility with old <2.0.0 XCA databases; use <= 2.3.0 to
  convert such a database first
+ wally <wally>
- rebuild for openssl 3.0.0

* Thu Dec 17 2020 umeabot <umeabot> 2.3.0-2.mga8
+ Revision: 1660301
- Rebuild for new Qt5

* Thu Nov 05 2020 daviddavid <daviddavid> 2.3.0-1.mga8
+ Revision: 1642761
- new version: 2.3.0

* Thu Feb 20 2020 umeabot <umeabot> 2.2.1-2.mga8
+ Revision: 1547657
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 2.2.1-1.mga8
+ Revision: 1488227
- new version: 2.2.1
- update URL and Source URL
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Tue Apr 02 2019 umeabot <umeabot> 1.3.2-6.mga7
+ Revision: 1385299
- Qt5 Rebuild

* Thu Oct 04 2018 umeabot <umeabot> 1.3.2-5.mga7
+ Revision: 1317397
- Mageia 7 Mass Rebuild

* Wed Sep 06 2017 cjw <cjw> 1.3.2-4.mga7
+ Revision: 1151605
- rebuild for openssl 1.1
- add patch from fedora to fix build with openssl 1.1

* Wed Dec 23 2015 dlucio <dlucio> 1.3.2-3.mga6
+ Revision: 913820
- rebuild for updated Qt5 buildrequirement

* Wed Dec 23 2015 dlucio <dlucio> 1.3.2-2.mga6
+ Revision: 913736
- use qt5

* Thu Nov 12 2015 tv <tv> 1.3.2-1.mga6
+ Revision: 902964
- adjust file list
- new release

* Sat Dec 27 2014 dlucio <dlucio> 1.1.0-1.mga5
+ Revision: 806373
- 1.1.0
- P0 merged upstream
- file list fixes

* Wed Oct 15 2014 umeabot <umeabot> 0.9.3-4.mga5
+ Revision: 740339
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.3-3.mga5
+ Revision: 690557
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0.9.3-2.mga4
+ Revision: 540635
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 dlucio <dlucio> 0.9.3-1.mga4
+ Revision: 494077
- 0.9.3
- website url updated

* Mon Jan 14 2013 umeabot <umeabot> 0.9.1-2.mga3
+ Revision: 386645
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 08 2011 dlucio <dlucio> 0.9.1-1.mga2
+ Revision: 165319
- 0.9.1
  P3 dropped

* Sat Oct 15 2011 dlucio <dlucio> 0.9.0-2.mga2
+ Revision: 155297
- trying to keep sync with mageia, more easy for me
- imported package xca

